@@ -1,3 +1,4 @@
+import contextlib
 import logging
 import typing as t
 import warnings
@@ -17,7 +18,43 @@ def initialize_mantik():
         warnings.warn(f"{e}\nCannot initialize mantik!")
 
 
-def log_metric_classification_report(truth: t.Sequence, predictions: t.Sequence, step: int = 1):
+def catch_mantik_exceptions(func):
+    def wrapper_do_twice(*args, **kwargs):
+        try:
+            func(*args, **kwargs)
+        except mlflow.exceptions.MlflowException as e:
+            logging.info(f"Ignoring mlflow exception:\n{e}")
+        else:
+            func(*args, **kwargs)
+
+    return wrapper_do_twice
+
+
+class Tracker:
+    def __init__(self) -> None:
+        initialize_mantik()
+
+    @catch_mantik_exceptions
+    def log_param(self, name, value):
+        mlflow.log_param(name, value)
+
+    @catch_mantik_exceptions
+    def log_params(self, params, **kwargs):
+        mlflow.log_params(params)
+
+    @contextlib.contextmanager
+    def start_run(self, *args, **kwargs):
+        yield mlflow.start_run(*args, **kwargs)
+
+    def end_run(self, *args, **kwargs):
+        mlflow.end_run(*args, **kwargs)
+
+    @catch_mantik_exceptions
+    def log_artifact(self, *args, **kwargs):
+        mlflow.log_artifact(*args, **kwargs)
+
+
+def log_metric_classification_report(tracker: Tracker, truth: t.Sequence, predictions: t.Sequence, step: int = 1):
     """
     Compute f1 score and logs results to mlflow
 
@@ -39,28 +76,28 @@ def log_metric_classification_report(truth: t.Sequence, predictions: t.Sequence,
         output_dict=True,
     )
     logging.info(classification_report)
-    log_classification_report(classification_report, step)
-    mlflow.log_artifact("confusion_matrix.pdf")
+    log_classification_report(tracker, classification_report, step)
+    tracker.log_artifact("confusion_matrix.pdf")
 
 
-def log_classification_report(classification_report, step):
+def log_classification_report(tracker, classification_report, step):
     initialize_mantik()
-    mlflow.log_metric(
+    tracker.log_metric(
         key="eval_f1_raining",
         value=classification_report["raining"]["f1-score"],
         step=step,
     )
-    mlflow.log_metric(
+    tracker.log_metric(
         key="eval_f1_not_raining",
         value=classification_report["not raining"]["f1-score"],
         step=step,
     )
-    mlflow.log_metric(
+    tracker.log_metric(
         key="weighted average f1-score",
         value=classification_report["weighted avg"]["f1-score"],
         step=step,
     )
-    mlflow.log_metric(
+    tracker.log_metric(
         key="macro average f1-score",
         value=classification_report["macro avg"]["f1-score"],
         step=step,
